function [egomaprotate] = egocentreMap(HeadPos,HeadOri,ObjectBound,mode)
% This function is to generate the raw egomap

% input:
% HeadPos is the mouse's headposition, 
% the 1st column corresponded to Y axis,
% the 2nd column corresponded to X axis. 
% e.g. [2 1; 4 5];
% HeadOri is the mouse's headorientation, the 1st column corresponded to Y axis, the 2nd column corresponded to X axis.
% ObjectBound is the definition of a object boundary. 
% it is a four number vector: [x1 x2 y1 y2]; (display with imshow function would have an inverted Y] 
% mode 0 is for the wall egocentric map calculation
% mode 2 is for the object egocentric map
Rid = 95; % the ridius of the egocentric map (pixel)

%% Setup a Big map and get a new coordinate in the object map
PosX1 = round(HeadPos(2))+128;
PosY1 = round(HeadPos(1))+96;
PosX2 = HeadOri(2)+128;
PosY2 = HeadOri(1)+96;

bigmap = zeros(384,512);
switch mode
    case 0% draw the wall
        bigmap(96+ObjectBound(3):96+ObjectBound(4),128+ObjectBound(1))=1;%setup left 1 Y1:Y2 X1
        bigmap(96+ObjectBound(3):96+ObjectBound(4),128+ObjectBound(2))=1;%setup right Y1:Y2 X2
        bigmap(96+ObjectBound(3),128+ObjectBound(1):128+ObjectBound(2))=1;%设置上边1
        bigmap(96+ObjectBound(4),128+ObjectBound(1):128+ObjectBound(2))=1;%设置下边1
    case 1 % bigmap is a circle
        Xobj = 96 +  (ObjectBound(3)+ObjectBound(4))/2;
        Yobj = 128 + (ObjectBound(1)+ObjectBound(2))/2;
        bigmap = DarwCircle(bigmap,[Xobj,Yobj],15);
    case 2 % bigmap is a square
        bigmap(96+ObjectBound(3):96+ObjectBound(4),128+ObjectBound(1):128+ObjectBound(2))=1;
end
%% rotate the allocentric map to a egocentric map
Vy = [0 -1];
Vm = [PosX2-PosX1,PosY2-PosY1];
ii = (-1)^(1/2);
A1 = 180*angle(Vy(1)+ii*Vy(2))/pi;
A2 = 180*angle(Vm(1)+ii*Vm(2))/pi;
Ad = A2-A1;

egomapraw = bigmap(PosY1-Rid:PosY1+Rid,PosX1-Rid:PosX1+Rid);
egomaprotate = imrotate(egomapraw,Ad,'bilinear','crop');
egomaprotate(egomaprotate>0) = 1;
egomaprotate = single(egomaprotate);


end